# Changelog

## 0.8.3 (2024-10-07)

Full Changelog: [v0.0.1-alpha.0...v0.8.3](https://github.com/mixpeek/python-client/compare/v0.0.1-alpha.0...v0.8.3)

### Chores

* add repr to PageInfo class ([#8](https://github.com/mixpeek/python-client/issues/8)) ([04d2ab3](https://github.com/mixpeek/python-client/commit/04d2ab37813edc8445f3597feeb95bb3e76b6fda))
* go live ([#6](https://github.com/mixpeek/python-client/issues/6)) ([d3ff4b5](https://github.com/mixpeek/python-client/commit/d3ff4b53231cc878afce6fa350c1650feb68c0e7))
* update SDK settings ([1f99fa6](https://github.com/mixpeek/python-client/commit/1f99fa6a533584eca8b7e5639c3e7106e1f4042a))
